#!/usr/local/bin/perl -w

=head1 NAME

copytestdirs.pl

=head1 SYNOPSIS

This is a wrapper over the UNIX "cp" command and creates copies of multiple test directories.

=head1 DESCRIPTION

See "copytestdirs.pl --help" for a list of options and their usage.

=head1 USAGE

See "copytestdirs.pl --help" for a list of options and their usage.

=head1 AUTHOR

Mahesh Joshi <joshi031@d.umn.edu>

Ted Pedersen <tpederse@d.umn.edu>

=head1 BUGS

=head1 SEE ALSO

wsdshell.pl

=head1 COPYRIGHT

Copyright (C) 2005, Ted Pedersen and Mahesh Joshi

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

=cut



use strict;

if (defined $ARGV[0] && $ARGV[0] eq "--help") {

    print "copytestdirs.pl: Perl Script to copy a set of test directories\n";
    print "in the WSDShell experiments as new directories. This is useful\n";
    print "for copying over the test directories when a significant part\n";
    print "of the next set of test cases is the same as earlier ones and\n";
    print "only a portion of them is to be repeated using the --step option\n";
    print "of the wsdshell.pl program.\n\n";

    print "USAGE: copytestdirs.pl SOURCE_START_INDEX " .
        "SOURCE_END_INDEX TARGET_START_INDEX\n\n";

    print "NOTE: The \"test\" prefix for the test directories is implicit.\n";
    print "Also, the testX directories should be in the current directory.\n\n";
    
    print "e.g. copytestdirs.pl 1 10 21\n\n";
    
    print "will create copies of directories test1 through test10 and the \n";
    print "new directories will be test21 through test30.\n";

    exit(0);
}

if (@ARGV != 3) {

    print "ERROR: Missing arguments!\n";
    print "USAGE: copytestdirs.pl SOURCE_START_INDEX " . 
    "SOURCE_END_INDEX TARGET_START_INDEX\n";
    print "See 'copytestdirs.pl --help' for details\n";

    exit(-1);
}

my $srcstart = shift;
my $srcend = shift;
my $targetstart = shift;

if ($srcstart < 0 || $srcend < 0 || $targetstart < 0 || $srcstart > $srcend) {

    die "ERROR: Please specify valid start and end numbers (greater than or equal to zero and (start number) <= (end number))\n";

}

my ($si, $ti);

for ($si = $srcstart, $ti = $targetstart; $si <= $srcend; $si++, $ti++) {

	my @args = ("cp", "-R", "test$si", "test$ti");
	print "@args...";
    
    system(@args) == 0
        or die "system @args failed: $?";
                
    print "done.\n";
}
