#!/usr/local/bin/perl -w

=head1 NAME

createcopies.pl

=head1 SYNOPSIS

This is a wrapper over the UNIX "cp" command and creates multiple copies of a given source directory.

=head1 DESCRIPTION

See "createcopies.pl --help" for a list of options and their usage.

=head1 USAGE

See "createcopies.pl --help" for a list of options and their usage.

=head1 AUTHOR

Mahesh Joshi <joshi031@d.umn.edu>

Ted Pedersen <tpederse@d.umn.edu>

=head1 BUGS

=head1 SEE ALSO

wsdshell.pl

=head1 COPYRIGHT

Copyright (C) 2005, Ted Pedersen and Mahesh Joshi

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

=cut

use strict;

if (defined $ARGV[0] && $ARGV[0] eq "--help") {

    print "createcopies.pl: Perl script to create multiple copies of\n";
    print "any source directory. The destination directories always\n";
    print "start with a prefix of \"test\".\n\n";

    print "USAGE: createcopies.pl SOURCE_DIR INITIAL_NO FINAL_NO\n\n";
 
    print "NOTE: The last two arguments are pure numbers mentioning the\n";
    print "suffix to be used for the pre-defined prefix \"test\" for the\n";
    print "test directories.\n\n";

    print "e.g. createcopies.pl ../NLMData 1 50\n\n";

    print "will create fifty copies of the NLM WSD collection directory with\n";
    print "names test1 through test50.\n";

    exit(0);
}

if (@ARGV != 3) {

    print "ERROR: Missing arguments.\n";
    print "USAGE: createcopies.pl SOURCE_DIR INITIAL_NO FINAL_NO\n";

    print "See 'createcopies.pl --help' for details.\n";

    exit(-1);
}

my $srcdir = shift @ARGV;

if (!-d $srcdir) {

    die "ERROR: Source directory $srcdir does not exist!\n";
}

my $start_num = shift @ARGV;
my $end_num = shift @ARGV;

if ($start_num < 0 || $end_num < 0 || $start_num > $end_num) {

    die "ERROR: Please specify valid start and end numbers (greater than or equal to zero and (start number) <= (end number))\n";

}

my $index;
for ($index = $start_num; $index <= $end_num; $index++) {

    my @args = ("cp", "-R", $srcdir, "test$index");
    print "@args...";

    system(@args) == 0 
        or die "system @args failed: $?";
    
    print "done.\n";
}
